{% if filetype_loop == 0 %}VRF,Address Family,Route,Active,Metric,Next Hop Index,Next Hop,Outgoing Interface,Route Preference,Source Protocol,Source Protocol Code{% for vrf in to_parse_routing %}{% for address_family in to_parse_routing[vrf].address_family %}{% for route in to_parse_routing[vrf].address_family[address_family].routes %}{% if to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.next_hop_list is defined %}{% for next_hop in to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.next_hop_list %}
{{ vrf }},{{ address_family }},{{ route }},{{ to_parse_routing[vrf].address_family[address_family].routes[route].active }},{{ to_parse_routing[vrf].address_family[address_family].routes[route].metric }},{{ next_hop }},{{ to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.next_hop_list[next_hop].next_hop }},N/A,{{ to_parse_routing[vrf].address_family[address_family].routes[route].route_preference }},{{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol }},{{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol_codes }}{% endfor %}{% else %}{% for outgoing_interface in to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.outgoing_interface %}
{{ vrf }},{{ address_family }},{{ route }},{{ to_parse_routing[vrf].address_family[address_family].routes[route].active }},N/A,N/A,N/A,{{ outgoing_interface }},N/A,{{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol }},{{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol_codes }}{% endfor %}{% endif %}{% endfor %}{% endfor %}{% endfor %}{% else %}{% if filetype_loop == 1 %}
# Learn Routing
| VRF | Address Family | Route | Active | Metric | Next Hop Index | Next Hop | Outgoing Interface | Route Preference | Source Protocol | Source Protocol Code |
| --- | -------------- | ----- | ------ | ------ | -------------- | -------- | -------------------| ---------------- | --------------- | -------------------- |{% for vrf in to_parse_routing %}{% for address_family in to_parse_routing[vrf].address_family %}{% for route in to_parse_routing[vrf].address_family[address_family].routes %}{% if to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.next_hop_list is defined %}{% for next_hop in to_parse_routing[vrf].address_family[address_family].routes.next_hop %}
| {{ vrf }} | {{ address_family }} | {{ route }} | {{ to_parse_routing[vrf].address_family[address_family].routes[route].active }} | {{ to_parse_routing[vrf].address_family[address_family].routes[route].metric }} | {{ next_hop }} | {{ to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.next_hop_list[next_hop].next_hop }} | N/A | {{ to_parse_routing[vrf].address_family[address_family].routes[route].route_preference }} | {{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol }} | {{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol_codes }} |{% endfor %}{% else %}{% for outgoing_interface in to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.outgoing_interface %}
| {{ vrf }} | {{ address_family }} | {{ route }} | {{ to_parse_routing[vrf].address_family[address_family].routes[route].active }} | N/A | N/A | N/A | {{ outgoing_interface }} | N/A | {{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol }} | {{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol_codes }} |{% endfor %}{% endif %}{% endfor %}{% endfor %}{% endfor %}{% else %}{% if filetype_loop == 2 %}
<html>
<head>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/dataTables.buttons.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.html5.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.print.min.js"></script>
    <script src="https://cdn.datatables.net/colreorder/1.5.4/js/dataTables.colReorder.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.colVis.min.js"></script>
    <script src="https://cdn.datatables.net/keytable/2.6.4/js/dataTables.keyTable.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.3.3/js/dataTables.select.min.js"></script>
    <script src="https://cdn.datatables.net/fixedheader/3.1.9/js/dataTables.fixedHeader.min.js"></script>
    <link rel="stylesheet" href="https://cdn.datatables.net/fixedheader/3.1.9/css/fixedHeader.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/select/1.3.3/css/select.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/keytable/2.6.4/css/keyTable.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.4/css/jquery.dataTables.min.css">
</head>
<body>
<h1>Learn Routing</h1>
<table id = "routing">
  <tr>
    <th>VRF</th>
    <th>Address Family</th>
    <th>Route</th>
    <th>Active</th>
    <th>Metric</th>
    <th>Next Hop Index</th>
    <th>Next Hop</th>
    <th>Outgoing Interface</th>
    <th>Route Preference</th>
    <th>Source Protocol</th>
    <th>Source Protocol Code</th>
  </tr>{% for vrf in to_parse_routing %}{% for address_family in to_parse_routing[vrf].address_family %}{% for route in to_parse_routing[vrf].address_family[address_family].routes %}{% if to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.next_hop_list is defined %}{% for next_hop in to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.next_hop_list %}
  {%                if loop.index is divisibleby 2 %}
  <tr style='background-color:#ddd'>
  {%-               else %}
  <tr>
  {%-               endif %}
    <td>{{ vrf }}</td>
    <td>{{ address_family }}</td>
    <td>{{ route }}</td>
    <td>{{ to_parse_routing[vrf].address_family[address_family].routes[route].active }}</td>
    <td>{{ to_parse_routing[vrf].address_family[address_family].routes[route].metric }}</td>
    <td>{{ next_hop }}</td>
    <td>{{ to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.next_hop_list[next_hop].next_hop }}</td>
    <td>N/A</td>
    <td>{{ to_parse_routing[vrf].address_family[address_family].routes[route].route_preference }}</td>
    <td>{{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol }}</td>
    <td>{{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol_codes }}</td>{% endfor %}{% else %}{% for outgoing_interface in to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.outgoing_interface %}
    <td>{{ vrf }}</td>
    <td>{{ address_family }}</td>
    <td>{{ route }}</td>
    <td>{{ to_parse_routing[vrf].address_family[address_family].routes[route].active }}</td>
    <td>N/A</td>
    <td>N/A</td>
    <td>N/A</td>
    <td>{{ outgoing_interface }}</td>
    <td>N/A</td>
    <td>{{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol }}</td>
    <td>{{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol_codes }}</td> 
  </tr>{% endfor %}{% endif %}{% endfor %}{% endfor %}{% endfor %}
</table>
<script type = "text/javascript">
  $(document).ready(function(){
    $('#routing thead tr')
    .clone(true)
    .addClass('filters')
    .appendTo('#routing thead');

    var table = $('#routing').DataTable({
        keys: true,
        dom: 'Bfrtip',
        lengthMenu: [
            [ 10, 25, 50, -1 ],
            [ '10 rows', '25 rows', '50 rows', 'Show all' ]
        ],
        buttons: [
        'pageLength','colvis','copy', 'csv', 'excel', 'pdf', 'print'
        ],
        colReorder: true,
        select: true,            
        orderCellsTop: true,
        fixedHeader: true,
        initComplete: function () {
        var api = this.api();

        // For each column
        api
            .columns()
            .eq(0)
            .each(function (colIdx) {
                // Set the header cell to contain the input element
                var cell = $('.filters th').eq(
                    $(api.column(colIdx).header()).index()
                );
                var title = $(cell).text();
                $(cell).html('<input type="text" placeholder="' + title + '" />');

                // On every keypress in this input
                $(
                    'input',
                    $('.filters th').eq($(api.column(colIdx).header()).index())
                )
                    .off('keyup change')
                    .on('keyup change', function (e) {
                        e.stopPropagation();

                        // Get the search value
                        $(this).attr('title', $(this).val());
                        var regexr = '({search})'; //$(this).parents('th').find('select').val();

                        var cursorPosition = this.selectionStart;
                        // Search the column for that value
                        api
                            .column(colIdx)
                            .search(
                                this.value != ''
                                    ? regexr.replace('{search}', '(((' + this.value + ')))')
                                    : '',
                                this.value != '',
                                this.value == ''
                            )
                            .draw();

                        $(this)
                            .focus()[0]
                            .setSelectionRange(cursorPosition, cursorPosition);
                    });
            });
    },
});
});        
</script>
</body></html>{% else %}
# Learn Routing
{%- for vrf in to_parse_routing %}
## VRF: {{ vrf }}
{%-     for address_family in to_parse_routing[vrf].address_family %}
### Address Family: {{ address_family }}
{%-         for route in to_parse_routing[vrf].address_family[address_family].routes %}
### Route: {{ route }}
### Active: {{ to_parse_routing[vrf].address_family[address_family].routes[route].active }}
### Metric: {{ to_parse_routing[vrf].address_family[address_family].routes[route].metric }}
{%-             if to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.next_hop_list is defined %}
{%-                 for next_hop in to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.next_hop_list %}
### Next Hop
#### {{ next_hop }}
#### Index: {{ to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.next_hop_list[next_hop].next_hop }}
{%-                 endfor %}
#### Route Preference: {{ to_parse_routing[vrf].address_family[address_family].routes[route].route_preference }}
### Source Protocol 
#### {{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol }}
#### Code: {{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol_codes }}
{%-             else %}
{%-                 for outgoing_interface in to_parse_routing[vrf].address_family[address_family].routes[route].next_hop.outgoing_interface %}
### Outgoing Interface: {{ outgoing_interface }}
{%-                 endfor %}
### Source Protocol 
#### {{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol }}
#### Code: {{ to_parse_routing[vrf].address_family[address_family].routes[route].source_protocol_codes }}
{%-             endif %}
{%-         endfor %}
{%-     endfor %}
{%- endfor %}
{%- endif %}{% endif %}{% endif %}